==> dotnet6_6.0.136.orig.tar.xz: src/runtime/src/libraries/Microsoft.Extensions.DependencyModel/src/DependencyContextStrings.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

namespace Microsoft.Extensions.DependencyModel
{
    internal static class DependencyContextStrings
    {
        internal const char VersionSeparator = '/';

        internal const string CompileTimeAssembliesKey = "compile";

        internal const string RuntimeAssembliesKey = "runtime";

        internal const string NativeLibrariesKey = "native";

        internal const string RuntimeTargetPropertyName = "runtimeTarget";

        internal const string LibrariesPropertyName = "libraries";

        internal const string TargetsPropertyName = "targets";

        internal const string DependenciesPropertyName = "dependencies";

        internal const string Sha512PropertyName = "sha512";

        internal const string PathPropertyName = "path";

        internal const string HashPathPropertyName = "hashPath";

        internal const string RuntimeStoreManifestPropertyName = "runtimeStoreManifestName";

        internal const string TypePropertyName = "type";

        internal const string ServiceablePropertyName = "serviceable";

        internal const string CompilationOptionsPropertName = "compilationOptions";

        internal const string DefinesPropertyName = "defines";

        internal const string LanguageVersionPropertyName = "languageVersion";

        internal const string PlatformPropertyName = "platform";

        internal const string AllowUnsafePropertyName = "allowUnsafe";

        internal const string WarningsAsErrorsPropertyName = "warningsAsErrors";

        internal const string OptimizePropertyName = "optimize";

        internal const string KeyFilePropertyName = "keyFile";

        internal const string DelaySignPropertyName = "delaySign";

        internal const string PublicSignPropertyName = "publicSign";

        internal const string DebugTypePropertyName = "debugType";

        internal const string EmitEntryPointPropertyName = "emitEntryPoint";

        internal const string GenerateXmlDocumentationPropertyName = "xmlDoc";

        internal const string PortablePropertyName = "portable";

        internal const string RuntimeTargetNamePropertyName = "name";

        internal const string RuntimeTargetSignaturePropertyName = "signature";

        internal const string RuntimesPropertyName = "runtimes";

        internal const string RuntimeTargetsPropertyName = "runtimeTargets";

        internal const string RidPropertyName = "rid";

        internal const string AssetTypePropertyName = "assetType";

        internal const string RuntimeAssetType = "runtime";

        internal const string NativeAssetType = "native";

        internal const string ResourceAssembliesPropertyName = "resources";

        internal const string LocalePropertyName = "locale";

        internal const string CompilationOnlyPropertyName = "compileOnly";

        internal const string AssemblyVersionPropertyName = "assemblyVersion";

        internal const string FileVersionPropertyName = "fileVersion";
    }
}

==> dotnet8_8.0.124-8.0.24.orig.tar.xz: src/runtime/src/libraries/Microsoft.Extensions.DependencyModel/src/DependencyContextStrings.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

namespace Microsoft.Extensions.DependencyModel
{
    internal static class DependencyContextStrings
    {
        internal const char VersionSeparator = '/';

        internal const string CompileTimeAssembliesKey = "compile";

        internal const string RuntimeAssembliesKey = "runtime";

        internal const string NativeLibrariesKey = "native";

        internal const string RuntimeTargetPropertyName = "runtimeTarget";

        internal const string LibrariesPropertyName = "libraries";

        internal const string TargetsPropertyName = "targets";

        internal const string DependenciesPropertyName = "dependencies";

        internal const string Sha512PropertyName = "sha512";

        internal const string PathPropertyName = "path";

        internal const string HashPathPropertyName = "hashPath";

        internal const string RuntimeStoreManifestPropertyName = "runtimeStoreManifestName";

        internal const string TypePropertyName = "type";

        internal const string ServiceablePropertyName = "serviceable";

        internal const string CompilationOptionsPropertyName = "compilationOptions";

        internal const string DefinesPropertyName = "defines";

        internal const string LanguageVersionPropertyName = "languageVersion";

        internal const string PlatformPropertyName = "platform";

        internal const string AllowUnsafePropertyName = "allowUnsafe";

        internal const string WarningsAsErrorsPropertyName = "warningsAsErrors";

        internal const string OptimizePropertyName = "optimize";

        internal const string KeyFilePropertyName = "keyFile";

        internal const string DelaySignPropertyName = "delaySign";

        internal const string PublicSignPropertyName = "publicSign";

        internal const string DebugTypePropertyName = "debugType";

        internal const string EmitEntryPointPropertyName = "emitEntryPoint";

        internal const string GenerateXmlDocumentationPropertyName = "xmlDoc";

        internal const string PortablePropertyName = "portable";

        internal const string RuntimeTargetNamePropertyName = "name";

        internal const string RuntimeTargetSignaturePropertyName = "signature";

        internal const string RuntimesPropertyName = "runtimes";

        internal const string RuntimeTargetsPropertyName = "runtimeTargets";

        internal const string RidPropertyName = "rid";

        internal const string AssetTypePropertyName = "assetType";

        internal const string RuntimeAssetType = "runtime";

        internal const string NativeAssetType = "native";

        internal const string ResourceAssembliesPropertyName = "resources";

        internal const string LocalePropertyName = "locale";

        internal const string CompilationOnlyPropertyName = "compileOnly";

        internal const string AssemblyVersionPropertyName = "assemblyVersion";

        internal const string FileVersionPropertyName = "fileVersion";
    }
}
